.. _api-index:

API reference
=============

This section recaps the main public modules and points to the narrative guides
where end-to-end examples live.

.. toctree::
   :maxdepth: 1

   overview
   metrics
   tsseg.metrics
   tsseg.algorithms
